import React from 'react';
import {
  DrawerForm,
  ProFormText,
  ProFormSelect,
  ProFormDigit,
  ProFormList,
  ProFormDependency
} from '@ant-design/pro-components';
import { Form, Row, Col } from 'antd';
import WangEditor from '@/components/Wangeditor';
import SearchSelect, { transformQuery } from '@/components/SearchSelect';
import { postTaCheckItemQu } from '@/service/tacheckitemqu';
import { getTdQuestion } from '@/service/tdquestion';

const queryQu = transformQuery(getTdQuestion, { searchKey: 'title', labelKey: 'title', valueKey: 'quId' });

export default (props) => {
  const {open, onOpenChange, quInfo, itemId, itemType, onChange} = props;
  const [form] = Form.useForm();

  const onFinish = async (values) => {
    const data = {
      ...(quInfo || {}),
      ...values,
      itemId,
    }

    const res = await postTaCheckItemQu(data);
    console.log(res)
    onChange(res);
    return true;
  }

  const onTplChange = (_, tpl) => {
    if (tpl) {
      form.resetFields();
      form.setFieldsValue({
        quType: tpl.quType,
        title: tpl.title,
        answerList: (tpl.quAnswerList || []).map(x => ({
          answerCode: x.answerCode,
          answer: x.answer,
        })),
      });
    }
  }

  React.useEffect(() => {
    if (quInfo) {
      form.setFieldsValue(quInfo);
    } else {
      form.resetFields();
    }
  }, [quInfo]);

  return (
    <DrawerForm
      title="问题维护"
      open={open}
      width={800}
      form={form}
      onFinish={onFinish}
      onOpenChange={onOpenChange}
      drawerProps={{
        destroyOnClose: true,
        extra: (
          <>
          {
            itemType == 'survey' && (
              <SearchSelect
                placeholder="请输入题干搜索题库"
                style={{width: '300px'}}
                request={queryQu}
                onChange={onTplChange}
              />
            )
          }
          </>
        )
      }}
    >
      <Row gutter={24}>
        <Col span={6}>
          <ProFormText
            name="sortNo"
            label="序号"
            placeholder="请填写"
            rules={[
              {
                required: true,
                message: '请填写序号',
              },
            ]}
          />
        </Col>
        <Col span={18}>
          <ProFormText
            name="title"
            label="题干描述"
            placeholder="请填写"
            rules={[
              {
                required: true,
                message: '请填写题干',
              },
            ]}
          />
        </Col>
      </Row>
      <Row gutter={24}>
        <Col span={12}>
          <ProFormSelect
            name="quType"
            label="问题类型"
            fieldProps={{
              style: { width: '100%' }
            }}
            valueEnum={{
              radio: '单选',
              fill: '填空'
            }}
            rules={[
              {
                required: true,
                message: '请选择问题类型',
              },
            ]}
          />
        </Col>
        <Col span={6}>
          <ProFormSelect
            name="computeType"
            label="计分方式"
            fieldProps={{
              style: { width: '100%' }
            }}
            valueEnum={{
              '+': '得分',
              '-': '扣分'
            }}
            rules={[
              {
                required: true,
                message: '请选择计分方式',
              },
            ]}
          />
        </Col>
        <Col span={6}>
          <ProFormDigit
            name="maxScore"
            label="最 高 分"
            min={0}
            fieldProps={{ precision: 2 }}
            rules={[
              {
                required: true,
                message: '请设置最高分',
              },
            ]}
          />
        </Col>
      </Row>
      <Row gutter={24}>
        <Col span={12}>
          <ProFormDependency name={['quType']}>
            {
              ({quType}) => (
                quType != 'fill' ? null : (
                  <ProFormDigit
                    name="anScore"
                    label="单项计分"
                    min={0}
                    fieldProps={{ precision: 2 }}
                    rules={[
                      {
                        required: true,
                        message: '请设置单项计分',
                      },
                    ]}
                  />
                )
              )
            }
          </ProFormDependency>
        </Col>
        <Col span={12}>
          <ProFormDependency name={['quType']}>
            {
              ({quType}) => (
                quType != 'fill' ? null : (
                  <ProFormText
                    name="fillUnit"
                    label="填空单位"
                    placeholder="表示填空数字的单位"
                  />
                )
              )
            }
          </ProFormDependency>
        </Col>
      </Row>
      {
        itemType == 'loc' && (
          <Form.Item name="stand" label="评分标准">
            <WangEditor
              height="200px"
              toolbarConfig={{
                toolbarKeys: [
                  'headerSelect',
                  'blockquote',
                  '|',
                  'bold',
                  'underline',
                  'italic',
                  'color',
                  'fontSize',
                  '|',
                  'bulletedList',
                  'numberedList',
                ]
              }}
            />
          </Form.Item>
        )
      }
      
      <ProFormDependency name={['quType']}>
        {
          ({quType}) => (
            quType == 'fill' ? null : (
              <ProFormList
                name="answerList"
                label="选项列表"
                copyIconProps={false}
              >
                <Row gutter={24} style={{ width: '730px' }}>
                  <Col span={6}>
                    <ProFormText
                      name="answerCode"
                      label="选项"
                      help="类似 A, B, C, D"
                    />
                  </Col>
                  <Col span={6}>
                    <ProFormDigit
                      name="score"
                      label="计分"
                      help="计分"
                      min={0}
                      fieldProps={{ precision: 2 }}
                    />
                  </Col>
                  <Col span={6}>
                    <ProFormSelect
                      name="reportIssue"
                      label="上报问题"
                      help="上报问题"
                      placeholder="是否上报问题"
                      valueEnum={{
                        0: '不上报',
                        1: '上报',
                      }}
                    />
                  </Col>
                  <Col span={6}>
                    <ProFormText
                      name="answer"
                      label="答案"
                      help="答案"
                      placeholder="具体选项内容"
                    />
                  </Col>
                </Row>
              </ProFormList>
            )
          )
        }
      </ProFormDependency>
    </DrawerForm>
  )
}
